package VMOMI::HostFeatureVersionKey;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
